@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 #
 # (c) Copyright 2003-2015 HP Development Company, L.P.
@@ -366,11 +366,13 @@ def get_xsane_version():
 
 def get_pil_version():
     try:
-        from PIL import Image
+       # from PIL import Image
+       import PIL
     except ImportError:
         return '-'
     else:
-         return Image.PILLOW_VERSION
+         #return Image.PILLOW_VERSION
+         return PIL.__version__
 
 def get_libpthread_version():
     try:
